@@ -59,7 +59,7 @@ extern "C" {
     F77_NAME(dcopy)(&pDet, REAL(muAlpha_r), &inc, muAlpha, &inc);
     double *SigmaBetaInv = (double *) R_alloc(ppOcc, sizeof(double));   
     F77_NAME(dcopy)(&ppOcc, REAL(SigmaBeta_r), &inc, SigmaBetaInv, &inc);
-    double sigmaAlpha = REAL(sigmaAlpha_r)[0]; 
+    double *sigmaAlpha = REAL(sigmaAlpha_r); 
     int J = INTEGER(J_r)[0];
     int *zLongIndx = INTEGER(zLongIndx_r); 
     int nObs = INTEGER(nObs_r)[0]; 
@@ -209,9 +209,9 @@ extern "C" {
     double *SigmaAlphaInv = (double *) R_alloc(currSize, sizeof(double)); zeros(SigmaAlphaInv, currSize); 
     double *SigmaAlphaInvMuAlpha = (double *) R_alloc(pDet, sizeof(double)); 
     // Fill SigmaAlpha
-    for (q = 0; q < nData; q++) {
-      for (i = 0; i < pDetLong[q]; i++) {
-        SigmaAlphaInv[alphaSigmaIndx[q] + i * pDetLong[q] + i] = sigmaAlpha; 
+    for (q = 0, j = 0; q < nData; q++) {
+      for (i = 0; i < pDetLong[q]; i++, j++) {
+        SigmaAlphaInv[alphaSigmaIndx[q] + i * pDetLong[q] + i] = sigmaAlpha[j]; 
 	// Rprintf("Index: %i\n", alphaSigmaIndx[q] + i * pDetLong[q] + i); 
       } // i
       F77_NAME(dpotrf)(lower, &pDetLong[q], &SigmaAlphaInv[alphaSigmaIndx[q]], &pDetLong[q], &info FCONE); 
